@@ -86,16 +86,6 @@ void                        eel_background_reset                            (Eel
 void                        eel_background_set_image_placement              (EelBackground               *background,
 									     EelBackgroundImagePlacement  placement);
 
-/* Set this if you know that the widget/window will never change its
- * size. This means that EelBackground can use background pixmaps
- * even for backgrounds that otherwise would change when the size
- * chages. The important user is the nautilus desktop window.
- *
- * This function can be deleted - it is a no-op. Users should call set_desktop() instead
- */
-void                        eel_background_set_is_constant_size             (EelBackground               *background,
-									     gboolean                     constant_size);
-
 /* Should be TRUE for desktop background */
 void			    eel_background_set_desktop 			    (EelBackground              *background,
 									     GtkWidget *widget, 
