@@ -845,8 +845,8 @@ static void
 pixbuf_destroy_callback (guchar  *pixels,
 			 gpointer callback_data)
 {
-	g_return_if_fail (pixels != NULL);
-	g_return_if_fail (callback_data != NULL);
+	g_assert (pixels != NULL);
+	g_assert (callback_data != NULL);
 
 	g_object_unref (callback_data);
 }
