@@ -27,7 +27,7 @@
 #define EEL_GTK_CONTAINER_H
 
 #include <gtk/gtkcontainer.h>
-#include <libart_lgpl/art_rect.h>
+#include <eel/eel-art-extensions.h>
 
 void eel_gtk_container_child_expose_event (GtkContainer   *container,
 					   GtkWidget      *child,
@@ -42,6 +42,6 @@ void eel_gtk_container_child_remove       (GtkContainer   *container,
 					   GtkWidget      *child);
 void eel_gtk_container_child_size_allocate (GtkContainer *container,
 					    GtkWidget *child,
-					    ArtIRect child_geometry);
+					    EelIRect child_geometry);
 
 #endif /* EEL_GTK_CONTAINER_H */
