@@ -585,13 +585,13 @@ static void
 while_realized_disconnecter (GtkObject *object,
 			     RealizeDisconnectInfo *info)
 {
-	g_return_if_fail (GTK_IS_OBJECT (object));
-	g_return_if_fail (info != NULL);
-	g_return_if_fail (GTK_IS_OBJECT (info->object));
-	g_return_if_fail (info->object_destroy_handler != 0);
-	g_return_if_fail (info->object_destroy_handler != 0);
-	g_return_if_fail (info->realized_widget_destroy_handler != 0);
-	g_return_if_fail (info->realized_widget_unrealized_handler != 0);
+	g_assert (GTK_IS_OBJECT (object));
+	g_assert (info != NULL);
+	g_assert (GTK_IS_OBJECT (info->object));
+	g_assert (info->object_destroy_handler != 0);
+	g_assert (info->object_destroy_handler != 0);
+	g_assert (info->realized_widget_destroy_handler != 0);
+	g_assert (info->realized_widget_unrealized_handler != 0);
 
  	g_signal_handler_disconnect (info->object, info->object_destroy_handler);
  	g_signal_handler_disconnect (info->object, info->signal_handler);
